@@ -1,6 +1,7 @@
 <?php
-/* Copyright (C) 2010      Regis Houssin       <regis.houssin@inodbox.com>
- * Copyright (C) 2010-2012 Laurent Destailleur <eldy@users.sourceforge.net>
+/* Copyright (C) 2010       Regis Houssin           <regis.houssin@inodbox.com>
+ * Copyright (C) 2010-2012  Laurent Destailleur     <eldy@users.sourceforge.net>
+ * Copyright (C) 2024       Frédéric France         <frederic.france@free.fr>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -16,10 +17,19 @@
  * along with this program. If not, see <https://www.gnu.org/licenses/>.
  */
 
+/**
+ * @var Canvas $this
+ * @var Conf $conf
+ * @var CommonObject $this
+ * @var Translate $langs
+ * @var User $user
+ *
+ * @var string $canvas
+ */
 // Protection to avoid direct call of template
 if (empty($conf) || !is_object($conf)) {
 	print "Error, template page can't be called as URL";
-	exit;
+	exit(1);
 }
 
 ?>
@@ -60,8 +70,8 @@ if (empty($conf) || !is_object($conf)) {
 
 <tr>
 	<td><span class="fieldrequired"><?php echo $langs->trans('ThirdPartyName'); ?></span></td>
-	<td><input type="text" size="30" maxlength="60" name="nom" value="<?php echo $this->control->tpl['nom']; ?>"></td>
-	<?php if (!empty($conf->global->SOCIETE_USEPREFIX)) { ?>
+	<td><input type="text" size="30" maxlength="60" name="name" value="<?php echo $this->control->tpl['name']; ?>"></td>
+	<?php if (getDolGlobalString('SOCIETE_USEPREFIX')) { ?>
 	<td><?php echo $langs->trans('Prefix'); ?></td>
 	<td><input type="text" size="5" maxlength="5" name="prefix_comm" value="<?php echo $this->control->tpl['prefix_comm']; ?>"></td>
 	<?php } ?>
@@ -114,7 +124,7 @@ if (isModEnabled('barcode')) { ?>
 
 <tr>
 	<td class="tdtop"><?php echo $langs->trans('Address'); ?></td>
-	<td colspan="3"><textarea name="adress" cols="40" rows="3"><?php echo $this->control->tpl['address']; ?></textarea></td>
+	<td colspan="3"><textarea name="address" cols="40" rows="3"><?php echo $this->control->tpl['address']; ?></textarea></td>
 </tr>
 
 <tr>
@@ -137,6 +147,8 @@ if (isModEnabled('barcode')) { ?>
 <tr>
 	<td><?php echo $langs->trans('Phone'); ?></td>
 	<td><input type="text" name="phone" value="<?php echo $this->control->tpl['phone']; ?>"></td>
+	<td><?php echo $langs->trans('PhoneMobile'); ?></td>
+	<td><input type="text" name="phone_mobile" value="<?php echo $this->control->tpl['phone_mobile']; ?>"></td>
 	<td><?php echo $langs->trans('Fax'); ?></td>
 	<td><input type="text" name="fax" value="<?php echo $this->control->tpl['fax']; ?>"></td>
 </tr>
@@ -207,7 +219,7 @@ for ($i = 1; $i <= 4; $i++) {
 	echo $this->control->tpl['localtax'];
 } ?>
 
-<?php if ($user->rights->societe->client->voir) { ?>
+<?php if ($user->hasRight('societe', 'client', 'voir')) { ?>
 <tr>
 	<td><?php echo $langs->trans("AllocateCommercial"); ?></td>
 	<td colspan="3"><?php echo $this->control->tpl['select_users']; ?></td>
